# RebbVal-Python

Python verion of RebbVal

## What is RebbVal

Is RebbVal a validation library? Nope, RebbVal is a external DSL for validation. It makes writing validation rules easier and more natural. Since it is more human readable than most of existing validation libraries, it means less bugs.

> A [domain-specific language](https://en.wikipedia.org/wiki/Domain-specific_language) (DSL) is a computer language specialized to a particular application domain.

## Document

* [English](https://willking.gitbook.io/rebb-val/)
* [Chinese](https://willking.gitbook.io/rebb-val/v/zh-cn/)

## Other Language

* [RebbVal-Java](https://github.com/tmfc/RebbVal)
* [RebbVal-JavaScript](https://github.com/tmfc/RebbVal-JS)
* [RebbVal-PHP](https://github.com/tmfc/RebbVal-PHP)
